sequencetools.partition_sequence_extended_to_counts
===================================================

.. autofunction:: abjad.tools.sequencetools.partition_sequence_extended_to_counts.partition_sequence_extended_to_counts
